/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import ClaySticker from '@clayui/sticker';
import PropType from 'prop-types';
import React from 'react';

import {getValueFromItem} from '../utilities/index';

function ImageRenderer(props) {
	return (
		<div className="row">
			<div className="col-auto">
				{typeof props.value === 'string' ? (
					<ClaySticker
						shape={props.options.shape || 'rounded'}
						size={props.options.size || 'xl'}
					>
						<div className="sticker-overlay">
							<img
								alt={
									props.options.label ||
									(props.options.labelKey
										? getValueFromItem(
												props.itemData,
												props.options.labelKey
										  )
										: Liferay.Language.get('thumbnail'))
								}
								className="sticker-img"
								src={props.value}
							/>
						</div>
					</ClaySticker>
				) : (
					<ClaySticker
						shape={
							props.options.shape ||
							props.value.shape ||
							'rounded'
						}
						size={props.options.size || props.value.size || 'xl'}
					>
						<div className="sticker-overlay">
							<img
								alt={
									props.value.alt ||
									Liferay.Language.get('thumbnail')
								}
								className="sticker-img"
								src={props.value.src}
							/>
						</div>
					</ClaySticker>
				)}
			</div>
		</div>
	);
}

ImageRenderer.propTypes = {
	options: PropType.shape({
		label: PropType.string,
		labelKey: PropType.oneOfType([PropType.array, PropType.string]),
		shape: PropType.string,
		size: PropType.string,
	}),
	value: PropType.oneOfType([
		PropType.shape({
			alt: PropType.string,
			shape: PropType.string,
			size: PropType.string,
			src: PropType.string.isRequired,
		}),
		PropType.string,
	]),
};

export default ImageRenderer;
