/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import getJsModule from '../utilities/modules';
import ActionsLinkRenderer from './ActionLinkRenderer';
import ActionsDropdownRenderer from './ActionsDropdownRenderer';
import CheckboxRenderer from './CheckboxRenderer';
import DateRenderer from './DateRenderer';
import DefaultRenderer from './DefaultRenderer';
import ImageRenderer from './ImageRenderer';
import LabelRenderer from './LabelRenderer';
import LinkRenderer from './LinkRenderer';
import ListRenderer from './ListRenderer';
import QuantitySelectorRenderer from './QuantitySelectorRenderer';
import StatusRenderer from './StatusRenderer';
import TooltipPriceRenderer from './TooltipPriceRenderer';

const dataRenderers = {
	actionLink: ActionsLinkRenderer,
	actionsDropdown: ActionsDropdownRenderer,
	checkbox: CheckboxRenderer,
	date: DateRenderer,
	default: DefaultRenderer,
	image: ImageRenderer,
	label: LabelRenderer,
	link: LinkRenderer,
	list: ListRenderer,
	quantitySelector: QuantitySelectorRenderer,
	status: StatusRenderer,
	tooltipPrice: TooltipPriceRenderer,
};

export function getDataRendererById(id) {
	return dataRenderers[id] || DefaultRenderer;
}

export const fetchedContentRenderers = [];

export function getDataRendererByURL(url) {
	return new Promise((resolve, reject) => {
		const addedDataRenderer = fetchedContentRenderers.find(
			(cr) => cr.url === url
		);
		if (addedDataRenderer) {
			resolve(addedDataRenderer.component);
		}

		return getJsModule(url)
			.then((fetchedComponent) => {
				fetchedContentRenderers.push({
					component: fetchedComponent,
					url,
				});

				return resolve(fetchedComponent);
			})
			.catch(reject);
	});
}
