/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import ClayButton from '@clayui/button';
import React from 'react';

import {useAppState} from './Context';
import FilterResume from './FilterResume';

function ActiveFiltersBar({disabled}) {
	const {actions, state} = useAppState();

	const filtersActive = state.filters.reduce(
		(acc, filter) =>
			filter.value && !filter.invisible ? acc.concat(filter.id) : acc,
		[]
	);

	return filtersActive.length ? (
		<div className="management-bar management-bar-light navbar navbar-expand-md">
			<div className="container-fluid container-fluid-max-xl">
				<nav className="mb-0 py-3 subnav-tbar subnav-tbar-light subnav-tbar-primary w-100">
					<ul className="tbar-nav">
						<li className="p-0 tbar-item tbar-item-expand">
							<div className="tbar-section">
								{filtersActive.map((id) => {
									const filter = state.filters.reduce(
										(found, filter) =>
											found ||
											(filter.id === id ? filter : null),
										null
									);

									if (!filter) {
										throw new Error(
											`Filter "${id}" not found.`
										);
									}

									return (
										<FilterResume
											disabled={disabled}
											key={filter.id}
											{...filter}
										/>
									);
								})}
							</div>
						</li>
						<li className="tbar-item">
							<div className="tbar-section">
								<ClayButton
									disabled={disabled}
									displayType="unstyled"
									onClick={actions.resetFiltersValue}
								>
									{Liferay.Language.get('reset-filters')}
								</ClayButton>
							</div>
						</li>
					</ul>
				</nav>
			</div>
		</div>
	) : null;
}

export default ActiveFiltersBar;
